==> lxqt-globalkeys_0.17.0.orig.tar.xz: lxqt-globalkeys-0.17.0/config/translations/lxqt-config-globalkeyshortcuts_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../default_model.cpp" line="51"/>
        <source>Command</source>
        <translation>Befehl</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="52"/>
        <source>DBus call</source>
        <translation>DBus-Aufruf</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="53"/>
        <source>Client</source>
        <translation>Client</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="143"/>
        <source>Id</source>
        <translation>Kennung</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="146"/>
        <source>Shortcut</source>
        <translation>Tastenkürzel</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="149"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="152"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="155"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Aktion bearbeiten</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>Ta&amp;stenkürzel:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Beschreibung:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>&amp;Aktiviert</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Befehl</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>&amp;DBus-Meldung</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>Be&amp;fehl:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>Di&amp;enst:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>&amp;Pfad:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translatorcomment>&amp;Schnittstelle:</translatorcomment>
        <translation>Schn&amp;ittstelle:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Methode:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation>Globale Aktionsverwaltung</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="55"/>
        <source>Add ...</source>
        <translation>Hinzufügen ...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="65"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="75"/>
        <source>Modify ...</source>
        <translation>Ändern ...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="92"/>
        <source>Swap</source>
        <translation>Tauschen</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="118"/>
        <source>Multiple actions behaviour:</source>
        <translation>Verhalten bei mehreren Aktionen:</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="126"/>
        <source>First</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Erste</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="131"/>
        <source>Last</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Letzte</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="136"/>
        <source>None</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Keine</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="141"/>
        <source>All</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Alle</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="166"/>
        <source>Default</source>
        <translation>Vorgabe</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="186"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="187"/>
        <source>Restore Default</source>
        <translation>Voreinstellungen wiederherstellen</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="188"/>
        <source>Your defined shortcuts will be removed.
Do you want to proceed?</source>
        <translation>Ihre definierten Tastaturbefehle werden entfernt. Möchten Sie fortfahren?</translation>
    </message>
</context>
</TS>

==> lxqt-globalkeys_2.1.0.orig.tar.xz: lxqt-globalkeys-2.1.0/config/translations/lxqt-config-globalkeyshortcuts_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../default_model.cpp" line="51"/>
        <source>Command</source>
        <translation>Befehl</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="52"/>
        <source>DBus call</source>
        <translation>DBus-Aufruf</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="53"/>
        <source>Client</source>
        <translation>Client</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="143"/>
        <source>Id</source>
        <translation>Kennung</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="146"/>
        <source>Shortcut</source>
        <translation>Tastenkürzel</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="149"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="152"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="155"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Aktion bearbeiten</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>Ta&amp;stenkürzel:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Beschreibung:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>&amp;Aktiviert</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Befehl</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>&amp;DBus-Meldung</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>Be&amp;fehl:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>Di&amp;enst:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>&amp;Pfad:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translatorcomment>&amp;Schnittstelle:</translatorcomment>
        <translation>Schn&amp;ittstelle:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Methode:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation>Globale Aktionsverwaltung</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="27"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="72"/>
        <source>Add ...</source>
        <translation>Hinzufügen ...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="82"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="92"/>
        <source>Modify ...</source>
        <translation>Ändern ...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="109"/>
        <source>Swap</source>
        <translation>Tauschen</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="135"/>
        <source>Multiple actions behaviour:</source>
        <translation>Verhalten bei mehreren Aktionen:</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="143"/>
        <source>First</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Erste</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="148"/>
        <source>Last</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Letzte</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="153"/>
        <source>None</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Keine</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="158"/>
        <source>All</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Alle</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="183"/>
        <source>Default</source>
        <translation>Vorgabe</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="207"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="191"/>
        <source>Restore Default</source>
        <translation>Voreinstellungen wiederherstellen</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="192"/>
        <source>Your defined shortcuts will be removed.
Do you want to proceed?</source>
        <translation>Ihre definierten Tastaturbefehle werden entfernt. Möchten Sie fortfahren?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Platform Unsupported</source>
        <translation>Plattform nicht unterstützt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>LXQt globalkeys are currently unsupported under Wayland.

Global shortcuts can be configured in the settings of the compositor instead.</source>
        <translation>LXQt globalkeys werden unter Wayland derzeit nicht unterstützt.

Globale Tastenkombinationen können stattdessen in den Einstellungen des Kompositors konfiguriert werden.</translation>
    </message>
</context>
</TS>
